@@ -12,6 +12,9 @@ from .type_exceptions import (
     TypeMismatchException,
 )
 
+from . import serializable_type
+from fprime.util.string_util import format_string_template
+
 
 class ArrayType(ValueType):
     """Generic fixed-size array type representation.
@@ -57,6 +60,22 @@ class ArrayType(ValueType):
         """
         return [item.val for item in self.__val]
 
+    @property
+    def formatted_val(self) -> list:
+        """
+        Format all the elements of array according to the arr_format.
+        Note 1: All elements will be cast to str
+        Note 2: If a member is a serializable will call serializable formatted_val
+        :return a formatted array
+        """
+        result = []
+        for item in self.__val:
+            if isinstance(item, (serializable_type.SerializableType, ArrayType)):
+                result.append(item.formatted_val)
+            else:
+                result.append(format_string_template(self.__arr_format, item.val))
+        return result
+
     @val.setter
     def val(self, val: list):
         """
