@@ -19,26 +19,23 @@ def full_path(path):
     return path.resolve()
 
 
+# The following tests use a fake framework path due to the separation of fprime and fprime-tools
+
+
 def test_settings():
     test_cases = [
-        {
-            "file": "nonexistent.ini",
-            "expected": {
-                "framework_path": full_path("../../../../.."),
-                "install_dest": full_path("settings-data/build-artifacts"),
-            },
-        },
         {
             "file": "settings-empty.ini",
             "expected": {
                 "settings_file": full_path("settings-data/settings-empty.ini"),
                 "default_toolchain": "native",
                 "default_ut_toolchain": "native",
-                "framework_path": full_path("../../../../.."),
+                "framework_path": full_path(".."),
                 "install_dest": full_path("settings-data/build-artifacts"),
                 "library_locations": [],
                 "environment_file": full_path("settings-data/settings-empty.ini"),
                 "environment": {},
+                "component_cookiecutter": "default",
             },
         },
         {
@@ -47,13 +44,14 @@ def test_settings():
                 "settings_file": full_path("settings-data/settings-custom-install.ini"),
                 "default_toolchain": "native",
                 "default_ut_toolchain": "native",
-                "framework_path": full_path("../../../../.."),
+                "framework_path": full_path(".."),
                 "install_dest": full_path("test"),
                 "library_locations": [],
                 "environment_file": full_path(
                     "settings-data/settings-custom-install.ini"
                 ),
                 "environment": {},
+                "component_cookiecutter": "default",
             },
         },
         {
@@ -64,21 +62,39 @@ def test_settings():
                 ),
                 "default_toolchain": "custom1",
                 "default_ut_toolchain": "custom2",
-                "framework_path": full_path("../../../../.."),
+                "framework_path": full_path(".."),
                 "install_dest": full_path("settings-data/build-artifacts"),
                 "library_locations": [],
                 "environment_file": full_path(
                     "settings-data/settings-custom-toolchain.ini"
                 ),
                 "environment": {},
+                "component_cookiecutter": "default",
+            },
+        },
+        {
+            "file": "settings-outside-cookiecutter.ini",
+            "expected": {
+                "settings_file": full_path(
+                    "settings-data/settings-outside-cookiecutter.ini"
+                ),
+                "default_toolchain": "native",
+                "default_ut_toolchain": "native",
+                "framework_path": full_path(".."),
+                "install_dest": full_path("settings-data/build-artifacts"),
+                "library_locations": [],
+                "environment_file": full_path(
+                    "settings-data/settings-outside-cookiecutter.ini"
+                ),
+                "environment": {},
+                "component_cookiecutter": "gh:SterlingPeet/cookiecutter-fprime-deployment",
             },
         },
     ]
 
     for case in test_cases:
         fp = full_path("settings-data/" + case["file"])
-        print(fp)
-        results = IniSettings.load(fp, LOCAL_PATH)
+        results = IniSettings.load(fp)
         assert case["expected"] == results, "{}: Expected {}, got {}".format(
             fp, case["expected"], results
         )
